.. _imaging:

Imaging ('xrayvision.imaging')
******************************

The ``imaging`` submodule contains functions to make map and images from visibilities.

.. automodapi:: xrayvision.imaging
